@@ -26,6 +26,8 @@ def _should_ignore(fd_name: str, patterns: Sequence[str]) -> bool:
 
 
 class FileDescriptorSetGenerator(abc.ABC):
+    """Base class that implements fixing imports."""
+
     def __init__(self, fdset_generator_binary: str) -> None:
         self.fdset_generator_binary = fdset_generator_binary
 
@@ -41,13 +43,16 @@ class FileDescriptorSetGenerator(abc.ABC):
         module_suffixes: Sequence[str],
         exclude_imports_glob: Sequence[str],
     ) -> None:
+        """Fix imports from protoc/buf generated code."""
         rewriters = {}
         fdset = FileDescriptorSet.FromString(self.generate_file_descriptor_set_bytes())
 
         for fd in fdset.file:
-            fd_name = _remove_proto_suffix(fd.name)
-            if _should_ignore(fd_name, exclude_imports_glob):
+            name = fd.name
+            if _should_ignore(name, exclude_imports_glob):
                 continue
+
+            fd_name = _remove_proto_suffix(name)
             rewriters[fd_name] = rewriter = ASTImportRewriter()
             # services live outside of the corresponding generated Python
             # module, but they import it so we register a rewrite for the
@@ -56,29 +61,24 @@ class FileDescriptorSetGenerator(abc.ABC):
             for repl in build_rewrites(fd_name, fd_name):
                 rewriter.register_rewrite(repl)
 
-            # register _proto_ import rewrites
-            for dep in fd.dependency:
-                dep_name = _remove_proto_suffix(dep)
-                if _should_ignore(dep_name, exclude_imports_glob):
+            # register proto import rewrites
+            for dep in map(_remove_proto_suffix, fd.dependency):
+                if _should_ignore(dep, exclude_imports_glob):
                     continue
+
+                dep_name = _remove_proto_suffix(dep)
                 for repl in build_rewrites(fd_name, dep_name):
                     rewriter.register_rewrite(repl)
 
-        for fd in fdset.file:
-            fd_name = _remove_proto_suffix(fd.name)
             for suffix in module_suffixes:
-                py_name = f"{fd_name}{suffix}"
-                python_file = python_out.joinpath(py_name)
-                if python_file.exists():
+                python_file = python_out.joinpath(f"{fd_name}{suffix}")
+                try:
                     raw_code = python_file.read_text()
-                    try:
-                        rewriter = rewriters[fd_name]
-                    except KeyError:
-                        # rewriters don't exist for glob-ignored names
-                        pass
-                    else:
-                        new_code = rewriter.rewrite(raw_code)
-                        overwrite_callback(python_file, new_code)
+                except FileNotFoundError:
+                    pass
+                else:
+                    new_code = rewriters[fd_name].rewrite(raw_code)
+                    overwrite_callback(python_file, new_code)
 
         if create_package:
             python_out.joinpath("__init__.py").touch(exist_ok=True)
@@ -93,11 +93,11 @@ class Protoc(FileDescriptorSetGenerator):
     def __init__(
         self,
         protoc_path: str,
-        paths: Iterable[Path],
+        proto_files: Iterable[Path],
         proto_paths: Iterable[Path],
     ) -> None:
         super().__init__(protoc_path)
-        self.paths = list(paths)
+        self.proto_files = list(proto_files)
         self.proto_paths = list(proto_paths)
 
     def generate_file_descriptor_set_bytes(self) -> bytes:
@@ -109,7 +109,7 @@ class Protoc(FileDescriptorSetGenerator):
                     "--include_imports",
                     f"--descriptor_set_out={filename}",
                     *map("--proto_path={}".format, self.proto_paths),
-                    *map(str, self.paths),
+                    *map(str, self.proto_files),
                 ]
             )
 
